pub trait BlockAccessListsClient: DownloadClient {
type Output: Future<Output = PeerRequestResult<BlockAccessLists>> + Send + Sync + Unpin;
// Required method
fn get_block_access_lists_with_priority_and_requirement(
&self,
hashes: Vec<B256>,
priority: Priority,
requirement: BalRequirement,
) -> Self::Output;
// Provided methods
fn get_block_access_lists(&self, hashes: Vec<B256>) -> Self::Output { ... }
fn get_block_access_lists_with_requirement(
&self,
hashes: Vec<B256>,
requirement: BalRequirement,
) -> Self::Output { ... }
fn get_block_access_lists_with_priority(
&self,
hashes: Vec<B256>,
priority: Priority,
) -> Self::Output { ... }
}Expand description
A client capable of downloading block access lists.
Required Associated Types
Sourcetype Output: Future<Output = PeerRequestResult<BlockAccessLists>> + Send + Sync + Unpin
type Output: Future<Output = PeerRequestResult<BlockAccessLists>> + Send + Sync + Unpin
The bal type this client fetches.
Required Methods
Sourcefn get_block_access_lists_with_priority_and_requirement(
&self,
hashes: Vec<B256>,
priority: Priority,
requirement: BalRequirement,
) -> Self::Output
fn get_block_access_lists_with_priority_and_requirement( &self, hashes: Vec<B256>, priority: Priority, requirement: BalRequirement, ) -> Self::Output
Fetches the block access lists for given hashes with priority and BAL availability policy.
Provided Methods
Sourcefn get_block_access_lists(&self, hashes: Vec<B256>) -> Self::Output
fn get_block_access_lists(&self, hashes: Vec<B256>) -> Self::Output
Fetches the block access lists for given hashes.
Sourcefn get_block_access_lists_with_requirement(
&self,
hashes: Vec<B256>,
requirement: BalRequirement,
) -> Self::Output
fn get_block_access_lists_with_requirement( &self, hashes: Vec<B256>, requirement: BalRequirement, ) -> Self::Output
Fetches the block access lists for given hashes with the requested BAL availability policy.
Sourcefn get_block_access_lists_with_priority(
&self,
hashes: Vec<B256>,
priority: Priority,
) -> Self::Output
fn get_block_access_lists_with_priority( &self, hashes: Vec<B256>, priority: Priority, ) -> Self::Output
Fetches the block access lists for given hashes with priority
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<'a, T: 'a + BlockAccessListsClient + ?Sized> BlockAccessListsClient for &'a Twhere
&'a T: DownloadClient,
impl<'a, T: 'a + BlockAccessListsClient + ?Sized> BlockAccessListsClient for &'a Twhere
&'a T: DownloadClient,
type Output = <T as BlockAccessListsClient>::Output
fn get_block_access_lists(&self, hashes: Vec<B256>) -> Self::Output
fn get_block_access_lists_with_requirement( &self, hashes: Vec<B256>, requirement: BalRequirement, ) -> Self::Output
fn get_block_access_lists_with_priority( &self, hashes: Vec<B256>, priority: Priority, ) -> Self::Output
fn get_block_access_lists_with_priority_and_requirement( &self, hashes: Vec<B256>, priority: Priority, requirement: BalRequirement, ) -> Self::Output
Sourceimpl<T: BlockAccessListsClient + ?Sized> BlockAccessListsClient for Arc<T>where
Arc<T>: DownloadClient,
impl<T: BlockAccessListsClient + ?Sized> BlockAccessListsClient for Arc<T>where
Arc<T>: DownloadClient,
type Output = <T as BlockAccessListsClient>::Output
fn get_block_access_lists(&self, hashes: Vec<B256>) -> Self::Output
fn get_block_access_lists_with_requirement( &self, hashes: Vec<B256>, requirement: BalRequirement, ) -> Self::Output
fn get_block_access_lists_with_priority( &self, hashes: Vec<B256>, priority: Priority, ) -> Self::Output
fn get_block_access_lists_with_priority_and_requirement( &self, hashes: Vec<B256>, priority: Priority, requirement: BalRequirement, ) -> Self::Output
Sourceimpl<T: BlockAccessListsClient + ?Sized> BlockAccessListsClient for Box<T>where
Box<T>: DownloadClient,
impl<T: BlockAccessListsClient + ?Sized> BlockAccessListsClient for Box<T>where
Box<T>: DownloadClient,
type Output = <T as BlockAccessListsClient>::Output
fn get_block_access_lists(&self, hashes: Vec<B256>) -> Self::Output
fn get_block_access_lists_with_requirement( &self, hashes: Vec<B256>, requirement: BalRequirement, ) -> Self::Output
fn get_block_access_lists_with_priority( &self, hashes: Vec<B256>, priority: Priority, ) -> Self::Output
fn get_block_access_lists_with_priority_and_requirement( &self, hashes: Vec<B256>, priority: Priority, requirement: BalRequirement, ) -> Self::Output
Implementors
Sourceimpl BlockAccessListsClient for TestFullBlockClient
Available on crate features test-utils only.
impl BlockAccessListsClient for TestFullBlockClient
Available on crate features
test-utils only.