SyncStateProvider

Trait SyncStateProvider 

pub trait SyncStateProvider: Send + Sync {
    // Required methods
    fn is_syncing(&self) -> bool;
    fn is_initially_syncing(&self) -> bool;
}
A type that provides information about whether the node is currently syncing and the network is currently serving syncing related requests.

Required Methods

fn is_syncing(&self) -> bool

Returns true if the network is undergoing sync.

fn is_initially_syncing(&self) -> bool

Returns true if the network is undergoing an initial (pipeline) sync.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, T: 'a + SyncStateProvider + ?Sized> SyncStateProvider for &'a T
where &'a T: Send + Sync,

Source

impl<T: SyncStateProvider + ?Sized> SyncStateProvider for Arc<T>
where Arc<T>: Send + Sync,

Source

impl<T: SyncStateProvider + ?Sized> SyncStateProvider for Box<T>
where Box<T>: Send + Sync,

Implementors